@@ -51,5 +51,5 @@ class EQPresetsSource(menus.ListPageSource):
         return embed
 
     def get_max_pages(self):
-        """:class:`int`: The maximum number of pages required to paginate this sequence."""
+        """:class:`int`: The maximum number of pages required to paginate this sequence"""
         return self._max_pages or 1
